==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QPropertyNodeAddedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a node is added to a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html">Qt3DCore::QPropertyNodeAddedChange</a></p>
 */
public class QPropertyNodeAddedChange extends io.qt.qt3d.core.QStaticPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#QPropertyNodeAddedChange">Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)</a></p>
     */
    @Deprecated
    public QPropertyNodeAddedChange(io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId, node);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyNodeAddedChange instance, io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#addedNodeId">Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId addedNodeId(){
        return addedNodeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId addedNodeId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#metaObject">Qt3DCore::QPropertyNodeAddedChange::metaObject()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPropertyNodeAddedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QPropertyNodeAddedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a node is added to a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html">Qt3DCore::QPropertyNodeAddedChange</a></p>
 */
public class QPropertyNodeAddedChange extends io.qt.qt3d.core.QStaticPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#QPropertyNodeAddedChange">Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)</a></p>
     */
    @Deprecated
    public QPropertyNodeAddedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId, io.qt.qt3d.core.@Nullable QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId, node);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyNodeAddedChange instance, io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#addedNodeId">Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId addedNodeId(){
        return addedNodeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId addedNodeId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynodeaddedchange.html#metaObject">Qt3DCore::QPropertyNodeAddedChange::metaObject()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QPropertyNodeAddedChange(QPrivateConstructor p) { super(p); } 
    
}
